@@ -123,7 +123,10 @@ def get_infos_from_file(
 
     log.info("Loading data from '{}'".format(str(lkrz_file_path)))
 
-    if s in lkrz:
+    top_players = {}
+    tournament = None
+
+    for s in lkrz:
         section = lkrz[s]
         if s == "Tournament":
             tournament = smashgg.Tournament(
@@ -189,7 +192,7 @@ def get_infos_from_url(
 
     url_parsed = urllib.parse.urlparse(url)
 
-    if url_parsed.netloc not in [ "smash.gg" ]:
+    if url_parsed.netloc not in [ "smash.gg", "start.gg" ]:
         raise ValueError("Unsupported domain name")
     if outform not in [ "dict", "lkrz" ]:
         raise ValueError("Unsupported outform")
@@ -199,7 +202,7 @@ def get_infos_from_url(
     event = None
 
     # -------------------------------------------------------------------------
-    if url_parsed.netloc == "smash.gg":
+    if url_parsed.netloc in [ "smash.gg", "start.gg" ]:
 
         if (url_parsed.path.split("/")[1] != "tournament"):
             log.error("Incomplete URL '{}'".format(url))
