@@ -8,7 +8,7 @@ import requests
 from .games import ssbu, melee, pplus
 
 # =============================================================================
-API_HOST = "api.smash.gg"
+API_HOST = "api.start.gg"
 API_ENDPOINT = "gql/alpha"
 API_SCHEME = "https"
 API_URL = "{scheme}://{host}/{endpoint}".format(
